==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityStatus Availability status. Possibles values: ENABLED, DISABLED.
 */
public data class DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs(
    public val availabilityStatus: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs> {
    override fun toJava():
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs.builder()
            .availabilityStatus(availabilityStatus?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgsBuilder internal
constructor() {
    private var availabilityStatus: Output<String>? = null

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("xjqrfcfdjeonwrkd")
    public suspend fun availabilityStatus(`value`: Output<String>) {
        this.availabilityStatus = value
    }

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("yowpkynmtarakcuv")
    public suspend fun availabilityStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.availabilityStatus = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs =
        DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs(
            availabilityStatus = availabilityStatus,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityStatus Availability status. Possibles values: ENABLED, DISABLED.
 */
public data class DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs(
    public val availabilityStatus: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs.builder()
            .availabilityStatus(availabilityStatus?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgsBuilder internal constructor() {
    private var availabilityStatus: Output<String>? = null

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("rqwpdwveqoettocu")
    public suspend fun availabilityStatus(`value`: Output<String>) {
        this.availabilityStatus = value
    }

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("eiuyfrpuuubwbhig")
    public suspend fun availabilityStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.availabilityStatus = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs =
        DashboardDashboardPublishOptionsExportWithHiddenFieldsOptionArgs(
            availabilityStatus = availabilityStatus,
        )
}
